@@ -334,10 +334,14 @@ sub prep {
 	print OUT $this->name." (".$this->version."-".$this->release.") experimental; urgency=low\n";
 	print OUT "\n";
 	print OUT "  * Converted from .".$this->origformat." format to .deb by alien version $Alien::Version\n";
+	print OUT "  \n";
+	if (defined $this->changelogtext) {
+		my $ct=$this->changelogtext;
+		$ct=~s/^/  /gm;
+		print OUT $ct."\n";
+	}
 	print OUT "\n";
 	print OUT " -- ".$this->username." <".$this->email.">  ".$this->date."\n";
-	print OUT "\n";
-	print OUT $this->changelogtext."\n" if defined $this->changelogtext;
 	close OUT;
 
 	# Control file.
